@@ -21,6 +21,7 @@ commands:
     search    Search Archive.org.
     mine      Download item metadata from Archive.org concurrently.
     catalog   Retrieve information about your Archive.org catalog tasks.
+    list      List files in a given item.
 
 See 'ia help <command>' for more information on a specific command.
 
@@ -57,6 +58,7 @@ def main():
             se = 'search',
             mi = 'mine',
             ca = 'catalog',
+            ls = 'list',
     )
     if cmd in aliases:
         cmd = aliases[cmd]
